import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Opsgenie User
 *
 * @schema CfnUserProps
 */
export interface CfnUserProps {
    /**
     * @schema CfnUserProps#OpsgenieApiEndpoint
     */
    readonly opsgenieApiEndpoint: string;
    /**
     * @schema CfnUserProps#OpsgenieApiKey
     */
    readonly opsgenieApiKey: string;
    /**
     * Opsgenie Username the mail address of the user
     *
     * @schema CfnUserProps#Username
     */
    readonly username: string;
    /**
     * User full name
     *
     * @schema CfnUserProps#FullName
     */
    readonly fullName: string;
    /**
     * User role, default is User
     *
     * @schema CfnUserProps#Role
     */
    readonly role: string;
}
/**
 * Converts an object of type 'CfnUserProps' to JSON representation.
 */
export declare function toJson_CfnUserProps(obj: CfnUserProps | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Atlassian::Opsgenie::User`
 *
 * @cloudformationResource Atlassian::Opsgenie::User
 * @stability external
 * @link https://github.com/opsgenie/opsgenie-cloudformation-resources
 */
export declare class CfnUser extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Atlassian::Opsgenie::User";
    /**
     * Resource props.
     */
    readonly props: CfnUserProps;
    /**
     * Attribute `Atlassian::Opsgenie::User.UserId`
     * @link https://github.com/opsgenie/opsgenie-cloudformation-resources
     */
    readonly attrUserId: string;
    /**
     * Create a new `Atlassian::Opsgenie::User`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnUserProps);
}
